Završni dokumenti | OiRA

Teme

# Završni dokumenti

Izvješće možete upotrijebiti kako biste:

- dostavili dokaze nadzornim tijelima;
- proslijedili informacije uključenim osobama (radnicima, predstavnicima za zaštitu na radu, poslodavcima, stručnjacima za sigurnost i zdravlje na radu itd.);
- pratili i ocijenili jesu li uvedene potrebne mjere;
- zabilježili svaku izmjenu ako se okolnosti promijene (zbog uvođenja novih strojeva, zapošljavanja novih radnika ili na temelju rezultata istraga nesreća itd.).

Izvješće možete spremiti na svoje računalo i ispisati ga. Možete u njega unositi izmjene ili dodavati nove informacije. Napominjemo da se promjene koje unesete u izvješće koje ste preuzeli NEĆE spremiti u alat OiRA.

## Vrste izvješća

Za različite svrhe dostupne su različite vrste izvješća. Vrste izvješća koje su dostupne u određenim alatima ovise o odlukama nacionalnog partnera za alat OiRA ili programera alata OiRA.

Dostupna izvješća.

### Potpuno izvješće

Format: Word / Office Open XML (.docx). Možete ga uređivati nakon preuzimanja.

U njemu su dostupne sve informacije i podatci koje ste unijeli tijekom postupka procjene rizika.

Upotrijebite ga za sljedeće: dostavljanje dokaza o procjeni rizika nadzornim tijelima (npr. inspektoratu rada).

### Plan mjera

Format: Excel / Office Open XML (.xlsx). Možete ga uređivati nakon preuzimanja.

U njemu su dostupne informacije o svim mjerama koje ste odlučili provesti.

Upotrijebite ga za sljedeće:

- aktivno praćenje provedbe mjera koje ste odabrali;
- upravljanje problemima/rizicima na svojem radnom mjestu (određene zadaće, stručno znanje, odgovornosti, rokovi).

### Pregled rizika

Format: Portable Document Format (.pdf). Ne možete ga uređivati nakon preuzimanja.

U njemu je dostupan pregled utvrđenih rizika.

Upotrijebite ga za sljedeće:

- izradu kratkog pregleda statusa rizika na svojem radnom mjestu;
- prosljeđivanje informacija uključenim osobama;
- praćenje toga jesu li rizici/mjere obrađeni na odgovarajući način.

### Pregled mjera

Format: Portable Document Format (.pdf). Ne možete ga uređivati nakon preuzimanja.

U njemu je dostupan kratak pregled mjera koje će se provesti.

Upotrijebite ga za sljedeće:

- izradu kratkog pregleda statusa mjera koje ste odlučiti provesti;
- prosljeđivanje informacija uključenim osobama;
- praćenje toga jesu li rizici/mjere obrađeni na odgovarajući način.

Scroll to top Load toolbar…
Back

## 4-reports.md

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More